from ..utils.enum import Enum


class Environment(Enum):

    production = "production"
    development = "development"

    @classmethod
    def current(cls):
        from ..utils.appEngine import AppEngine
        projectId = AppEngine.getProjectId()
        return cls.development if "dev" in projectId else cls.production


class Microservice(Enum):

    transfer = "transfer"
    charge = "charge"
    refund = "refund"
    workspace = "workspace"
    bank = "bank"
    gateway = "gateway"

    @classmethod
    def getBaseUrl(cls, ms):
        return "https://%s.appspot.com" % cls.getProjectId(ms)

    @classmethod
    def getProjectId(cls, ms):
        return {
            Environment.production: _productionProjectId.get(ms),
            Environment.development: _developmentProjectId.get(ms)
        }[Environment.current()]


class Webapp:

    @classmethod
    def getBaseUrl(cls):
        return {
            Environment.production:  "https://darwin-web.appspot.com",
            Environment.development: "https://dev-dot-darwin-web.appspot.com"
        }[Environment.current()]


_developmentProjectId = {
    Microservice.transfer:  "api-ms-transfer-dev",
    Microservice.charge:    "api-ms-charge-dev.",
    Microservice.refund:    "api-ms-refund-dev",
    Microservice.workspace: "api-ms-workspace-dev",
    Microservice.bank:      "api-ms-bank-dev",
    Microservice.gateway:   "api-ms-gateway-dev"
}

_productionProjectId = {
    Microservice.transfer:  "api-ms-transfer",
    Microservice.charge:    "api-ms-charge",
    Microservice.refund:    "api-ms-refund",
    Microservice.workspace: "api-ms-workspace",
    Microservice.bank:      "api-ms-bank",
    Microservice.gateway:   "api-ms-gateway"
}